Type: Package
Package: tidytext
Title: Text Mining using 'dplyr', 'ggplot2', and Other Tidy Tools
Version: 0.4.3
Authors@R: c(
    person("Gabriela", "De Queiroz", , "gabidequeiroz@gmail.com", role = "ctb"),
    person("Colin", "Fay", , "contact@colinfay.me", role = "ctb",
           comment = c(ORCID = "0000-0001-7343-1846")),
    person("Emil", "Hvitfeldt", , "emilhhvitfeldt@gmail.com", role = "ctb"),
    person("Os", "Keyes", , "ironholds@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-5196-609X")),
    person("Kanishka", "Misra", , "kmisra@purdue.edu", role = "ctb"),
    person("Tim", "Mastny", , "tim.mastny@gmail.com", role = "ctb"),
    person("Jeff", "Erickson", , "jeff@erick.so", role = "ctb"),
    person("David", "Robinson", , "admiral.david@gmail.com", role = "aut"),
    person("Julia", "Silge", , "julia.silge@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3671-836X"))
  )
Description: Using tidy data principles can make many text mining tasks
    easier, more effective, and consistent with tools already in wide use.
    Much of the infrastructure needed for text mining with tidy data
    frames already exists in packages like 'dplyr', 'broom', 'tidyr', and
    'ggplot2'. In this package, we provide functions and supporting data
    sets to allow conversion of text to and from tidy formats, and to
    switch seamlessly between tidy tools and existing text mining
    packages.
License: MIT + file LICENSE
URL: https://juliasilge.github.io/tidytext/,
        https://github.com/juliasilge/tidytext
BugReports: https://github.com/juliasilge/tidytext/issues
Depends: R (>= 2.10)
Imports: cli, dplyr (>= 1.1.1), generics, janeaustenr, lifecycle,
        Matrix, methods, purrr (>= 0.1.1), rlang (>= 0.4.10), stringr,
        tibble, tokenizers, vctrs
Suggests: broom, covr, data.table, ggplot2, hunspell, knitr, mallet,
        NLP, quanteda, readr, reshape2, rmarkdown, scales, stm,
        stopwords, testthat (>= 2.1.0), textdata, tidyr, tm,
        topicmodels, vdiffr, wordcloud
VignetteBuilder: knitr
Config/Needs/website: ropensci/gutenbergr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: TRUE
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-07-25 01:12:50 UTC; juliasilge
Author: Gabriela De Queiroz [ctb],
  Colin Fay [ctb] (ORCID: <https://orcid.org/0000-0001-7343-1846>),
  Emil Hvitfeldt [ctb],
  Os Keyes [ctb] (ORCID: <https://orcid.org/0000-0001-5196-609X>),
  Kanishka Misra [ctb],
  Tim Mastny [ctb],
  Jeff Erickson [ctb],
  David Robinson [aut],
  Julia Silge [aut, cre] (ORCID: <https://orcid.org/0000-0002-3671-836X>)
Maintainer: Julia Silge <julia.silge@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-25 05:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:50:55 UTC; unix
