# Generated by roxygen2: do not edit by hand

S3method(augment,CTM)
S3method(augment,LDA)
S3method(augment,STM)
S3method(augment,jobjRef)
S3method(glance,CTM)
S3method(glance,LDA)
S3method(glance,STM)
S3method(glance,corpus)
S3method(glance,estimateEffect)
S3method(tidy,CTM)
S3method(tidy,Corpus)
S3method(tidy,DocumentTermMatrix)
S3method(tidy,LDA)
S3method(tidy,STM)
S3method(tidy,TermDocumentMatrix)
S3method(tidy,corpus)
S3method(tidy,dfm)
S3method(tidy,dfmSparse)
S3method(tidy,dictionary2)
S3method(tidy,estimateEffect)
S3method(tidy,jobjRef)
S3method(tidy,simple_triplet_matrix)
export(augment)
export(bind_tf_idf)
export(cast_dfm)
export(cast_dtm)
export(cast_sparse)
export(cast_tdm)
export(get_sentiments)
export(get_stopwords)
export(glance)
export(reorder_func)
export(reorder_within)
export(scale_x_reordered)
export(scale_y_reordered)
export(tidy)
export(unnest_character_shingles)
export(unnest_characters)
export(unnest_lines)
export(unnest_ngrams)
export(unnest_paragraphs)
export(unnest_ptb)
export(unnest_regex)
export(unnest_sentences)
export(unnest_skip_ngrams)
export(unnest_tokens)
export(unnest_tweets)
import(Matrix)
import(dplyr)
import(janeaustenr)
import(rlang)
import(tokenizers)
importFrom(dplyr,enquo)
importFrom(generics,augment)
importFrom(generics,glance)
importFrom(generics,tidy)
importFrom(lifecycle,deprecated)
importFrom(vctrs,vec_rep_each)
importFrom(vctrs,vec_slice)
