#' English negators, modals, and adverbs
#'
#' English negators, modals, and adverbs, as a data frame. A few of these
#' entries are two-word phrases instead of single words.
#'
#' @format A data frame with 44 rows and 2 variables:
#' \describe{
#'  \item{word}{An English word or bigram}
#'  \item{modifier}{The modifier type for `word`, either "negator",
#'  "modal", or "adverb"}
#'  }
#'
#' @source <http://saifmohammad.com/WebPages/SCL.html#NMA>
"nma_words"
